function [] = Plot_Resize( Fig, FigOpt, AxesOpt, LineOpt )
% Handle( Fig ):                       h = figure(#),                gcf
% Handle( Axes ):                      get(figure(1),'CurrentAxes'), gca
% Handel( XYZ-Label text object ): get(get(figure(1),'CurrentAxes'),'XLabel')
% Handel( TITLE     text object ): get(get(figure(3),'CurrentAxes'),'Title')

%%
%===============================
% LEGEND font:      match AXIS FontName/Size properties
%                   set(get(figure(1),'CurrentAxes'), 'FontName','Times')
Axes_h = get(figure(Fig),'CurrentAxes');
set(Axes_h, ...
    'FontName',AxesOpt.Font_Name,'FontSize',AxesOpt.Font_Size_Leg, ...
    'FontWeight',AxesOpt.Font_Weight);
%===============================
% AXIS LABEL font:  manually reset (1) XYZ-Label properties (2)xyz-label command
%                   set(get(get(figure(1),'CurrentAxes'),'XLabel'), 'FontName','Times')
%                   set(get(get(figure(1),'CurrentAxes'),'YLabel'), 'FontName','Times')
set(get(Axes_h,'XLabel'), ...
    'FontName',AxesOpt.Font_Name,'FontSize',AxesOpt.Font_Size, ...
    'FontWeight',AxesOpt.Font_Weight);
set(get(Axes_h,'YLabel'), ...
    'FontName',AxesOpt.Font_Name,'FontSize',AxesOpt.Font_Size, ...
    'FontWeight',AxesOpt.Font_Weight);
%===============================
% TITLE font:       manually reset (1) Title properties (2)title command
%                   set(get(get(figure(3),'CurrentAxes'),'Title'),'FontName','Times')
set(get(Axes_h,'Title'), ...
    'FontName',AxesOpt.Font_Name,'FontSize',AxesOpt.Font_Size, ...
    'FontWeight',AxesOpt.Font_Weight);
%===============================
% LineWidth: get(Axes_h,'LineWidth')
set(Axes_h,'LineWidth', AxesOpt.Ln_Width);

%===============================
% MarkerSize:
Line_h = get(Axes_h,'Children');
for nL = 1 : length( Line_h )
    set(Line_h(nL),'MarkerSize', LineOpt.Mkr_Size);
    set(Line_h(nL),'LineWidth', LineOpt.Ln_Width);
end

%===============================
    % Fig Size:         set(figure(1), 'Units','inches', 'Position',[left, bottom, width, height])
    %                   set(figure(1), 'Units','inches', 'Position',[1, 1, 3.5*2, 3.5*2])
    set(figure(Fig), 'Units','inches',  ...
        'Position',[1, 1, FigOpt.Pos_Width, FigOpt.Pos_Height]);

%% TEST
if(0)

FigOpt = struct('Pos_Width',3.5*2, 'Pos_Height',3*2);% saved to eps as is: too large
%    'Pos_Width',6, 'Pos_Height',5);
AxesOpt = struct('Font_Name','Times', 'Font_Weight','normal', ...
    'Font_Size',12, 'Font_Size_Leg',12, ...
    'Ln_Width',1);
LineOpt = struct('Mkr_Size',8, ...
    'Ln_Width',1);

for Fig = 1 : 4
    Plot_Resize( Fig, FigOpt, AxesOpt, LineOpt );
end

for Fig = 1 : 4
    Fig_FileNam = get(figure(Fig), 'FileName')
    %=============================== Figure Export Setup
    %get(figure(Fig),'Color')
    %get(figure(Fig),'Colormap')
    set(figure(Fig), 'Color','w', ...% white background
        ...% 'Colormap',[1 1 1; 0 0 0] Colormap as BlackWhite
        'PaperPositionMode','auto', 'PaperUnits','inches', ...% 'manual' 'auto'=WYSIWYG printing,   'normalized',   'PaperType','A4','usletter'
        'Renderer','painters', 'RendererMode','manual');% painters: faster for simple/small   'auto' 'manual'
    %=============================== Figure Export Setup
switch( 20 )
    case{10}%=============================== tiff
        export_fig(figure(Fig),[Fig_FileNam(1:end-3) 'tif'], '-tif', ...
        '-nocrop','-r600','-a1','-painters','-bw')% '-bw' '-grey' ('-rgb' not able to check b.c auto grey-detect)
    case{11}%-------------------------------
        saveas(figure(Fig),[Fig_FileNam(1:end-3) 'tiff'],'tiff')% can't spec DPI
    case{12}%------------------------------- always 24bits: can't spec Grey=8bit/BlackWhite=1bit
        print(['-f' num2str(figure(Fig))],'-painters','-dtiff','-r600',[Fig_FileNam(1:end-3) 'tif'])
    case{20}%=============================== eps (problems: resolution + cmyk instead of rgb)
        export_fig(figure(Fig),[Fig_FileNam(1:end-3) 'eps'], '-eps', ...
        '-nocrop','-r600','-a1','-painters', '-rgb')% '-grey' '-rgb' ('-cmyk' file error)
    case{21}%-------------------------------
        saveas(figure(Fig),[Fig_FileNam(1:end-3) 'eps'],'eps2')% can't embed fonts
    case{22}%-------------------------------
        print(['-f' num2str(figure(Fig))],'-painters','-deps2','-r600',[Fig_FileNam(1:end-3) 'eps'])
end
end

%------------------------------------- plotyy: use in future for multiple axis
x2 = [-7 -5 -3.5 -2.5 -2.4 -1.2 -1 -0.5 -0.499 -0.25 -0.2 -0.1 -0.0999 -0.05036 -0.05 -0.025 -0.02 -0.0107 -0.01 -0.00536];
x2 = [x2 fliplr(-x2)];
y1 = [-34.71 -34.236 -33.758 -33.329 -33.276 -32.411 -32.238 -31.611 -31.61 -34.656 -35.121 -36.717 -36.736 -38.9768 ...
    -38.9775 -39.579 -40.54 -43.673 -44.162 -61.695];
y1 = [y1 fliplr(y1)];
y2 = [-135.3 -140.3 -145.7 -150.7 -151.8 -170.3 -174.3 -189.3 -189.35 -197.3 -201 -212.1 -212.3 -210.6 -210.65 ...
    -221.3 -234.4 -268.4 -272.7 -365.3 -354.7 -447.3 -451.6 -485.6 -498.7 -509.3 -509.36 -507.7 -507.8 -519 -522.7 ...
    -530.6 -530.7 -545.7 -549.7 -568.1 -569.2 -574.3 -579.7 -584.7];
figure(1)
hl1 = line(x2,y1,  'Color','k','Marker','o','LineWidth',2,'MarkerSize',8);
ax1 = gca;
    set(ax1,'YLim',[-150 -30])
    set(ax1,'XTick',[-8:2:8],'YTick',[-150:40:-30])
    xlabel( ax1, 'Frequency (MHz)', 'FontName','Times','FontSize',12,'FontWeight','normal');
    ylabel( ax1, 'dB', 'FontName','Times','FontSize',12,'FontWeight','normal');
    set(ax1, 'FontName','Times','FontSize',12,'FontWeight','normal');
    set(ax1,'Position',[0.11500    0.1100    0.770    0.8150])
ax2 = axes('Position',get(ax1,'Position'), 'YAxisLocation','right','Color','none');
hl2 = line(x2,y2,'Parent',ax2,  'Color','k','Marker','x','LineWidth',2,'MarkerSize',8);
    set(ax2,'YLim',[-590 -30])
    set(ax2,'XTick',[-8:2:8],'YTick',[-590:40:-30])
    ylabel( ax2, 'Deg', 'FontName','Times','FontSize',12,'FontWeight','normal');
    set(ax2, 'FontName','Times','FontSize',12,'FontWeight','normal');
%legend('Final Estimate Phase', 'FontName','Times','FontSize',14,'FontWeight','normal', 'Location','Best');

end